/*******************************************************************************
* File Name: ISR_UI.c  
* Version 1.60
*
*  Description:
*   API for controlling the state of an interrupt.
*
*
*  Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/


#include <CYDEVICE.H>
#include <CYDEVICE_TRM.H>
#include <CYLIB.H>
#include <ISR_UI.H>


/*******************************************************************************
*  Place your includes, defines and code here 
********************************************************************************/
/* `#START ISR_UI_intc` */

/* `#END` */

#ifndef CYINT_IRQ_BASE
#define CYINT_IRQ_BASE	16
#endif
#ifndef CYINT_VECT_TABLE
#define CYINT_VECT_TABLE    ((cyisraddress **) CYREG_NVIC_VECT_OFFSET)
#endif

/* Declared in startup, used to set unused interrupts to. */
CY_ISR_PROTO(IntDefaultHandler);

/*******************************************************************************
* Function Name: ISR_UI_Start
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   void.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_UI_Start(void)
{
    /* For all we know the interrupt is active. */
    ISR_UI_Disable();

    /* Set the ISR to point to the ISR_UI Interrupt. */
    ISR_UI_SetVector(ISR_UI_Interrupt);

    /* Set the priority. */
    ISR_UI_SetPriority(ISR_UI_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISR_UI_Enable();
}

/*******************************************************************************
* Function Name: ISR_UI_StartEx
********************************************************************************
* Summary:
*  Set up the interrupt and enable it.
*
* Parameters:  
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_UI_StartEx(cyisraddress address)
{
    /* For all we know the interrupt is active. */
    ISR_UI_Disable();

    /* Set the ISR to point to the ISR_UI Interrupt. */
    ISR_UI_SetVector(address);

    /* Set the priority. */
    ISR_UI_SetPriority(ISR_UI_INTC_PRIOR_NUMBER);

    /* Enable it. */
    ISR_UI_Enable();
}

/*******************************************************************************
* Function Name: ISR_UI_Stop
********************************************************************************
* Summary:
*   Disables and removes the interrupt.
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
void ISR_UI_Stop(void) 
{
    /* Disable this interrupt. */
    ISR_UI_Disable();

    /* Set the ISR to point to the passive one. */
    ISR_UI_SetVector(IntDefaultHandler);
}

/*******************************************************************************
* Function Name: ISR_UI_Interrupt
********************************************************************************
* Summary:
*   The default Interrupt Service Routine for ISR_UI.
*
*   Add custom code between the coments to keep the next version of this file
*   from over writting your code.
*
*
*
* Parameters:  
*
*
* Return:
*   void.
*
*******************************************************************************/
CY_ISR(ISR_UI_Interrupt)
{
    /*  Place your Interrupt code here. */
    /* `#START ISR_UI_Interrupt` */

    /* `#END` */
}

/*******************************************************************************
* Function Name: ISR_UI_SetVector
********************************************************************************
* Summary:
*   Change the ISR vector for the Interrupt. Note calling ISR_UI_Start
*   will override any effect this method would have had. To set the vector before
*   the component has been started use ISR_UI_StartEx instead.
*
*
* Parameters:
*   address: Address of the ISR to set in the interrupt vector table.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_UI_SetVector(cyisraddress address) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    ramVectorTable[CYINT_IRQ_BASE + ISR_UI__INTC_NUMBER] = address;
}

/*******************************************************************************
* Function Name: ISR_UI_GetVector
********************************************************************************
* Summary:
*   Gets the "address" of the current ISR vector for the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Address of the ISR in the interrupt vector table.
*
*
*******************************************************************************/
cyisraddress ISR_UI_GetVector(void) 
{
    cyisraddress * ramVectorTable;

    ramVectorTable = (cyisraddress *) *CYINT_VECT_TABLE;

    return ramVectorTable[CYINT_IRQ_BASE + ISR_UI__INTC_NUMBER];
}

/*******************************************************************************
* Function Name: ISR_UI_SetPriority
********************************************************************************
* Summary:
*   Sets the Priority of the Interrupt. Note calling ISR_UI_Start
*   or ISR_UI_StartEx will override any effect this method would have had. 
*	This method should only be called after ISR_UI_Start or 
*	ISR_UI_StartEx has been called. To set the initial
*	priority for the component use the cydwr file in the tool.
*
*
* Parameters:
*   priority: Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_UI_SetPriority(uint8 priority) 
{
    *ISR_UI_INTC_PRIOR = priority << 5;
}

/*******************************************************************************
* Function Name: ISR_UI_GetPriority
********************************************************************************
* Summary:
*   Gets the Priority of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   Priority of the interrupt. 0 - 7, 0 being the highest.
*
*
*******************************************************************************/
uint8 ISR_UI_GetPriority(void) 
{
    uint8 priority;


    priority = *ISR_UI_INTC_PRIOR >> 5;

    return priority;
}

/*******************************************************************************
* Function Name: ISR_UI_Enable
********************************************************************************
* Summary:
*   Enables the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_UI_Enable(void) 
{
    /* Enable the general interrupt. */
    *ISR_UI_INTC_SET_EN = ISR_UI__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_UI_GetState
********************************************************************************
* Summary:
*   Gets the state (enabled, disabled) of the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   1 if enabled, 0 if disabled.
*
*
*******************************************************************************/
uint8 ISR_UI_GetState(void) 
{
    /* Get the state of the general interrupt. */
    return (*ISR_UI_INTC_SET_EN & ISR_UI__INTC_MASK) ? 1:0;
}

/*******************************************************************************
* Function Name: ISR_UI_Disable
********************************************************************************
* Summary:
*   Disables the Interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_UI_Disable(void) 
{
    /* Disable the general interrupt. */
    *ISR_UI_INTC_CLR_EN = ISR_UI__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_UI_SetPending
********************************************************************************
* Summary:
*   Causes the Interrupt to enter the pending state, a software method of
*   generating the interrupt.
*
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_UI_SetPending(void) 
{
    *ISR_UI_INTC_SET_PD = ISR_UI__INTC_MASK;
}

/*******************************************************************************
* Function Name: ISR_UI_ClearPending
********************************************************************************
* Summary:
*   Clears a pending interrupt.
*
* Parameters:
*   void.
*
*
* Return:
*   void.
*
*
*******************************************************************************/
void ISR_UI_ClearPending(void) 
{
    *ISR_UI_INTC_CLR_PD = ISR_UI__INTC_MASK;
}
