/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <device.h>
#include <stdbool.h>
#include <stdio.h>

#include "pwm_if.h"

#define NO_FINGER    (0xFFFF)


//CY_ISR_PROTO(timerUpdate); 

uint16 targetValue=30;

bool onState=false;
bool didSwitch=false;
bool didDim=false;
bool lastWasUp=true;
uint16 dsDelay=0;

CY_ISR(uiUpdate) 
{
	Timer_UI_ReadStatusRegister();
	LCD_Char_ClearDisplay();
	
	LCD_Char_Position(0,0);
	LCD_Char_PrintString("tgt=");
	LCD_Char_PrintNumber(targetValue);

	LCD_Char_Position(0,8);
	LCD_Char_PrintString("ADC=");
	LCD_Char_PrintNumber(PWM_LED_GetCurrentInputValue());
	
	LCD_Char_Position(1,0);
//	LCD_Char_PrintNumber(adcSum2);
//	LCD_Char_PrintString("/");
//	LCD_Char_PrintNumber(adcCount2);
	LCD_Char_PrintString("PWM=");
	LCD_Char_PrintNumber(PWM_LED_GetCurrentOutputValue());
	
	char buf[12];
	sprintf(buf,"err=%i",PWM_LED_GetCurrentErrorValue());
	LCD_Char_Position(1,8);
	LCD_Char_PrintString(buf);
	
	bool oldOnState=onState;
	int dsStatus=Status_Reg_DS_Read();
	if (0!=dsStatus) // hand detected
	{
		dsDelay++;
		if (onState) // if already on
		{
			if (dsDelay>10)  // and hand detected longer than 1 second
			{
				didDim=true;
				int16 tv=targetValue;
				if (lastWasUp)
					tv-=2;
				else
					tv+=2;
				if (tv<0)
					tv=0;
				if (tv>100)
					tv=100;
				targetValue=tv;
			}
		}
		else // if not on already
		{
			if (dsDelay>2) // switch on after 200ms
			{
				onState=true; // if off, and longer detection, switch on first, then dim down
				didSwitch=true;
				targetValue=100;
				lastWasUp=true;
			}
		}
	}
	else // no hand detected
	{
		// short movement only -> toggle state
		if (dsDelay<10 && dsDelay>1 && !didSwitch)
		{
			onState=!onState;
			if (onState)
			{
				targetValue=100;
				lastWasUp=true;
			}
			else
				targetValue=0;
		}
		// if we dimmed down to 0, its like switching it off
		if (0==targetValue)
			onState=false;
		if (didDim)
			lastWasUp=!lastWasUp;
			
		dsDelay=0;
		didSwitch=false;
		didDim=false;
	}
	if (oldOnState!=onState)
	{
		Control_Reg_PWM_Write(onState?0:1); // set kill bit accordingly, if we changed state
	}
	oldOnState=onState;
	LED4_Write(onState?1:0);
}

void main()
{
    CyGlobalIntEnable;
	
	//                 Kp,  Ki,  Kd,     Ta,   factor
	PWM_LED_SetFactors(0.4, 3.5, 0.0001, 0.01, 3.2);
    PWM_LED_SetOutputMinValue(10);
	PWM_LED_SetInputMaxValue(340);
	PWM_LED_SetTargetValue(30);
	
	Control_Reg_PWM_Write(1); // off on start

	LCD_Char_Start();
	LCD_Char_PrintString("run");

	ISR_Update_PWM_Start();
	ISR_ADC_FB_Start();
	ISR_UI_StartEx(&uiUpdate);
	
	Clock_Update_PWM_Start();
	Clock_Update_UI_Start();
	Clock_PWM_Start();
	Clock_ADC_Start();
	Clock_DS_Start();
	
	Opamp_FB_Start();
	ADC_SAR_FB_Start();
	ADC_SAR_FB_IRQ_Enable();
	ADC_SAR_FB_StartConvert();

	CapSense_Start();
    CapSense_InitializeAllBaselines();
    CapSense_ScanEnabledWidgets();

	CapSense_EnableWidget(CapSense_LINEARSLIDER__LS);
	LCD_Char_PrintString(".");


	LCD_Char_PrintString(".");
	
	PWM_LED_Start();
	LCD_Char_PrintString(".");

	Timer_Update_PWM_Start();
	Timer_UI_Start();
	LCD_Char_PrintString(".");

	LCD_Char_PrintString(".");

	uint16 lastSliderPos=50;
	
	LCD_Char_ClearDisplay();
	
	Comp_DS_Start();
	
	VDAC8_DS_Start();
	
    
	for(;;)
    {
	    if(!CapSense_IsBusy())
	    {
	        CapSense_UpdateEnabledBaselines();
	        CapSense_ScanEnabledWidgets();
			uint16 sliderPos=CapSense_GetCentroidPos(CapSense_LINEARSLIDER__LS);
		    if(sliderPos != NO_FINGER && onState)
			{
				if (sliderPos!=lastSliderPos)
				{
					sliderPos=(sliderPos);
					lastSliderPos=sliderPos;
					targetValue=(uint16)sliderPos;
					PWM_LED_SetTargetValue(targetValue);
				}
			}
		}
//		CyDelay(1);
		PWM_LED_SetTargetValue(targetValue);
    }
}

/* [] END OF FILE */
